==> qmmp-plugin-pack-1.0.2.tar.bz2: qmmp-plugin-pack-1.0.2/src/Input/mpg123/translations/mpg123_plugin_he.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="he">
<context>
    <name>DecoderMPG123Factory</name>
    <message>
        <location filename="../decodermpg123factory.cpp" line="111"/>
        <source>MPG123 Plugin</source>
        <translation>תוספת MPG123</translation>
    </message>
    <message>
        <location filename="../decodermpg123factory.cpp" line="114"/>
        <source>MPEG Files</source>
        <translation>קבצי MPEG</translation>
    </message>
    <message>
        <location filename="../decodermpg123factory.cpp" line="267"/>
        <source>About MPG123 Audio Plugin</source>
        <translation>אודות תוספת שמע MPG123</translation>
    </message>
    <message>
        <location filename="../decodermpg123factory.cpp" line="268"/>
        <source>Qmmp MPG123 Audio Plugin</source>
        <translation>תוספת שמע MPG123 של Qmmp</translation>
    </message>
    <message>
        <location filename="../decodermpg123factory.cpp" line="269"/>
        <source>This plugin provides MPEG v1/2 layer1/2/3 support
with use of libmpg123 library</source>
        <translation>תוספת זו מספקת תמיכה עבור MPEG v1/2 layer1/2/3
באמצעות ספריית libmpg123</translation>
    </message>
    <message>
        <location filename="../decodermpg123factory.cpp" line="271"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>חוברה על ידי: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;‎</translation>
    </message>
</context>
<context>
    <name>MPEGMetaDataModel</name>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="70"/>
        <source>Format</source>
        <translation>פורמט</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="72"/>
        <source>Bitrate</source>
        <translation>שיעור סיביות</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="72"/>
        <source>kbps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="74"/>
        <source>Sample rate</source>
        <translation>שיעור דגימה</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="74"/>
        <source>Hz</source>
        <translation>הרץ</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="78"/>
        <location filename="../mpegmetadatamodel.cpp" line="81"/>
        <location filename="../mpegmetadatamodel.cpp" line="84"/>
        <location filename="../mpegmetadatamodel.cpp" line="87"/>
        <source>Mode</source>
        <translation>מצב</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="90"/>
        <source>KB</source>
        <translation>ק״ב</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="91"/>
        <source>File size</source>
        <translation>גודל קובץ</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="93"/>
        <location filename="../mpegmetadatamodel.cpp" line="95"/>
        <source>Protection</source>
        <translation>הגנה</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="93"/>
        <location filename="../mpegmetadatamodel.cpp" line="97"/>
        <location filename="../mpegmetadatamodel.cpp" line="101"/>
        <source>Yes</source>
        <translation>כן</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="95"/>
        <location filename="../mpegmetadatamodel.cpp" line="99"/>
        <location filename="../mpegmetadatamodel.cpp" line="103"/>
        <source>No</source>
        <translation>לא</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="97"/>
        <location filename="../mpegmetadatamodel.cpp" line="99"/>
        <source>Copyright</source>
        <translation>זכויות יוצרים</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="101"/>
        <location filename="../mpegmetadatamodel.cpp" line="103"/>
        <source>Original</source>
        <translation>מקורי</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>MPEG Plugin Settings</source>
        <translation>הגדרות תוספת MPEG</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Tag Priority</source>
        <translation>עדיפות תגית</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="41"/>
        <source>First:</source>
        <translation>ראשונה:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="61"/>
        <location filename="../settingsdialog.ui" line="110"/>
        <location filename="../settingsdialog.ui" line="159"/>
        <source>ID3v1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="66"/>
        <location filename="../settingsdialog.ui" line="115"/>
        <location filename="../settingsdialog.ui" line="164"/>
        <source>ID3v2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="71"/>
        <location filename="../settingsdialog.ui" line="120"/>
        <location filename="../settingsdialog.ui" line="169"/>
        <source>APE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="76"/>
        <location filename="../settingsdialog.ui" line="125"/>
        <location filename="../settingsdialog.ui" line="174"/>
        <source>Disabled</source>
        <translation>מנוטרלת</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="90"/>
        <source>Second:</source>
        <translation>שניה:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="139"/>
        <source>Third:</source>
        <translation>שלישית:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="198"/>
        <source>Encodings</source>
        <translation>קידודים</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="210"/>
        <source>ID3v1 encoding:</source>
        <translation>קידוד ID3v1:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="236"/>
        <source>ID3v2 encoding:</source>
        <translation>קידוד ID3v2:</translation>
    </message>
</context>
</TS>

==> qmmp-plugin-pack-1.0.3.tar.bz2: qmmp-plugin-pack-1.0.3/src/Input/mpg123/translations/mpg123_plugin_he.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="he">
<context>
    <name>DecoderMPG123Factory</name>
    <message>
        <location filename="../decodermpg123factory.cpp" line="111"/>
        <source>MPG123 Plugin</source>
        <translation>תוסף MPG123</translation>
    </message>
    <message>
        <location filename="../decodermpg123factory.cpp" line="114"/>
        <source>MPEG Files</source>
        <translation>קבצי MPEG</translation>
    </message>
    <message>
        <location filename="../decodermpg123factory.cpp" line="267"/>
        <source>About MPG123 Audio Plugin</source>
        <translation>אודות תוסף שמע MPG123</translation>
    </message>
    <message>
        <location filename="../decodermpg123factory.cpp" line="268"/>
        <source>Qmmp MPG123 Audio Plugin</source>
        <translation>תוסף שמע MPG123 של Qmmp</translation>
    </message>
    <message>
        <location filename="../decodermpg123factory.cpp" line="269"/>
        <source>This plugin provides MPEG v1/2 layer1/2/3 support
with use of libmpg123 library</source>
        <translation>תוסף זה מספק תמיכה עבור MPEG v1/2 layer1/2/3
באמצעות ספריית libmpg123</translation>
    </message>
    <message>
        <location filename="../decodermpg123factory.cpp" line="271"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>חובר על ידי: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;‎</translation>
    </message>
</context>
<context>
    <name>MPEGMetaDataModel</name>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="70"/>
        <source>Format</source>
        <translation>פורמט</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="72"/>
        <source>Bitrate</source>
        <translation>שיעור סיביות</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="72"/>
        <source>kbps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="74"/>
        <source>Sample rate</source>
        <translation>שיעור דגימה</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="74"/>
        <source>Hz</source>
        <translation>הרץ</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="78"/>
        <location filename="../mpegmetadatamodel.cpp" line="81"/>
        <location filename="../mpegmetadatamodel.cpp" line="84"/>
        <location filename="../mpegmetadatamodel.cpp" line="87"/>
        <source>Mode</source>
        <translation>מצב</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="90"/>
        <source>KB</source>
        <translation>ק״ב</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="91"/>
        <source>File size</source>
        <translation>גודל קובץ</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="93"/>
        <location filename="../mpegmetadatamodel.cpp" line="95"/>
        <source>Protection</source>
        <translation>הגנה</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="93"/>
        <location filename="../mpegmetadatamodel.cpp" line="97"/>
        <location filename="../mpegmetadatamodel.cpp" line="101"/>
        <source>Yes</source>
        <translation>כן</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="95"/>
        <location filename="../mpegmetadatamodel.cpp" line="99"/>
        <location filename="../mpegmetadatamodel.cpp" line="103"/>
        <source>No</source>
        <translation>לא</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="97"/>
        <location filename="../mpegmetadatamodel.cpp" line="99"/>
        <source>Copyright</source>
        <translation>זכויות יוצרים</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="101"/>
        <location filename="../mpegmetadatamodel.cpp" line="103"/>
        <source>Original</source>
        <translation>מקורי</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>MPEG Plugin Settings</source>
        <translation>הגדרות תוסף MPEG</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Tag Priority</source>
        <translation>עדיפות תגית</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="41"/>
        <source>First:</source>
        <translation>ראשונה:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="61"/>
        <location filename="../settingsdialog.ui" line="110"/>
        <location filename="../settingsdialog.ui" line="159"/>
        <source>ID3v1</source>
        <translation>ID3v1</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="66"/>
        <location filename="../settingsdialog.ui" line="115"/>
        <location filename="../settingsdialog.ui" line="164"/>
        <source>ID3v2</source>
        <translation>ID3v2</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="71"/>
        <location filename="../settingsdialog.ui" line="120"/>
        <location filename="../settingsdialog.ui" line="169"/>
        <source>APE</source>
        <translation>APE</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="76"/>
        <location filename="../settingsdialog.ui" line="125"/>
        <location filename="../settingsdialog.ui" line="174"/>
        <source>Disabled</source>
        <translation>מנוטרלת</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="90"/>
        <source>Second:</source>
        <translation>שניה:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="139"/>
        <source>Third:</source>
        <translation>שלישית:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="198"/>
        <source>Encodings</source>
        <translation>קידודים</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="210"/>
        <source>ID3v1 encoding:</source>
        <translation>קידוד ID3v1:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="236"/>
        <source>ID3v2 encoding:</source>
        <translation>קידוד ID3v2:</translation>
    </message>
</context>
</TS>
